import React, { PropTypes } from 'react'
import Markdown from 'react-remarkable'
import { css } from 'glamor'
import Box from './Box'
import theme from './theme'

const contentStyles = {
  '& > *': {
    margin: 0,
    padding: 0,
    border: 0,
    fontSize: '100%',
    font: 'inherit',
    verticalAlign: 'baseline'
  },
  '& ol, & ul': {
    listStyle: 'none'
  },
  '& blockquote, & q': {
    quotes: 'none'
  },
  '& h1': {
    ...theme.textStyles.display1,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h2': {
    ...theme.textStyles.display2,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h3': {
    ...theme.textStyles.display3,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h4, & h5, & h6': {
    ...theme.textStyles.display4,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& p, & ul, & ol': {
    ...theme.textStyles.body1,
    maxWidth: '40em',
    margin: '1em 0'
  },
  '& ul': {
    listStyle: 'disc',
    listStylePosition: 'outside',
    marginLeft: '1.2em',
    padding: 0
  },
  '& ol': {
    listStyle: 'decimal'
  },
  '& em': {
    fontStyle: 'italic'
  },
  '& strong': {
    fontWeight: 500
  },
  '& p > code, & li > code, & table code': {
    ...theme.textStyles.body1,
    fontFamily: theme.fonts.sans,
    display: 'inline-block',
    backgroundColor: theme.colors.tint[0],
    boxShadow: `inset 0 0 0 1px ${theme.colors.tint[1]}`,
    padding: '0 0.5em',
    borderRadius: theme.borderRadius[0],

    '&:before, &:after': {
      content: '\\00a0',
      letterSpacing: '-0.2em'
    }
  },
  '& pre': {
    margin: '1em 0',
    overflowX: 'auto',
    textAlign: 'left',
    display: 'block',
    whiteSpace: 'pre',
    backgroundColor: theme.colors.tint[0],
    boxShadow: `inset 0 0 0 1px ${theme.colors.tint[1]}`,
    padding: theme.space[3],
    borderRadius: theme.borderRadius[0]
  },
  '& pre code': {
    ...theme.textStyles.mono,
    fontFamily: theme.fonts.mono,
    padding: 0,
    background: 'none',
    '&:before, &:after': {
      content: 'none',
      letterSpacing: 0
    }
  },
  '& hr': {
    background: theme.colors.tint[1],
    border: 0,
    height: '1px',
    margin: '32px 0'
  },
  '& table': {
    borderCollapse: 'collapse',
    borderSpacing: 0,
    width: '100%',
    margin: '1em 0'
  },
  '& thead': {
    borderBottom: `1px solid ${theme.colors.tint[1]}`,
    backgroundColor: theme.colors.tint[0],
    position: 'relative',
    textAlign: 'left',
    padding: '0 20px',
    boxSizing: 'content-box'
  },
  '& th': {
    fontWeight: '500'
  },
  '& tbody tr': {
    borderBottom: `1px solid ${theme.colors.tint[1]}`,
    background: theme.colors.white[0]
  },
  '& td, & th': {
    padding: '0.8em'
  }
}

const parseProps = ({ children, ...props }) => {
  if (typeof children === 'string') {
    return { children: <Markdown source={children} />, ...props }
  }
  return { children, ...props }
}

const Content = ({ markdown, ...props }) =>
  <Box {...css(contentStyles)} {...parseProps(props)} />

Content.propTypes = {
  markdown: PropTypes.bool
}

Content.displayName = 'Content'

export default Content
