import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Pane from './Pane'
import theme from './theme'

const fadeInAnimation = css.keyframes('fadeInAnimation', {
  from: {
    backgroundColor: `rgba(66,94,120,.0)`
  },
  to: {
    backgroundColor: `rgba(66,94,120,.8)`
  }
})

const fadeOutAnimation = css.keyframes('fadeOutAnimation', {
  from: {
    backgroundColor: `rgba(66,94,120,.8)`
  },
  to: {
    backgroundColor: `rgba(66,94,120,.0)`
  }
})

const OverlayPane = ({ fadeOut, ...props }) => <Pane {...css({
  zIndex: 10,
  transform: `translateZ(0)`,
  animation: `${fadeOut ? fadeOutAnimation : fadeInAnimation} ${theme.animationDuration.slow} ${theme.animationEasing.standard}`
})} {...props} />

OverlayPane.propTypes = {
  fadeOut: PropTypes.bool
}

OverlayPane.defaultProps = {
  position: 'fixed',
  top: 0,
  right: 0,
  bottom: 0,
  left: 0,
  backgroundColor: 'rgba(66, 94, 120, .8)'
}

OverlayPane.displayName = 'OverlayPane'

class Overlay extends React.Component {
  componentDidMount () {
    document.body.style.overflow = 'hidden'
  }

  componentWillUnmount () {
    document.body.style.overflow = 'initial'
  }

  render () {
    return <OverlayPane {...this.props} />
  }
}

export default Overlay
