import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Box from './Box'
import DoubleTriangle from './DoubleTriangle'
import theme from './theme'
import splitProps from '../utils/splitProps'

const SelectWrapperBox = props => <Box {...css({
  '& select': {
    border: 'none',
    appearance: 'none',
    color: theme.backgrounds.white.textColor,
    boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
    backgroundColor: 'white'
  },
  '& > select:focus, & > select:active': {
    outline: 'none',
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary[0]}`
  }
})} {...props} />

SelectWrapperBox.displayName = 'SelectWrapperBox'

const SelectIcon = props => <DoubleTriangle {...props} />

SelectIcon.defaultProps = {
  fill: theme.colors.darkTint[0],
  position: 'absolute',
  style: {
    transform: 'translateY(-50%)',
    pointerEvents: 'none'
  },
  top: '50%',
  right: '12px'
}

SelectIcon.displayName = 'SelectIcon'

const Select = (props) => {
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display/gi)

  return (
    <SelectWrapperBox position='relative' display='flex' {...matchedProps}>
      <SelectIcon />
      <Box flex='1' {...unmatchedProps} />
    </SelectWrapperBox>
  )
}

Select.defaultProps = {
  is: 'select',
  rounded: true,
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Select.displayName = 'Select'

export default Select
