import React, { Component, PropTypes } from 'react'
import { css } from 'glamor'
import Box from './Box'
import Pane from './Pane'
import Overlay from './Overlay'
import Close from './Close'
import theme from './theme'

const rotate360InAnimation = css.keyframes('rotate360InAnimation', {
  from: {
    transform: `translateX(100%) rotate(0deg)`
  },
  to: {
    transform: `translateX(-100%) rotate(-360deg)`
  }
})

const rotate360OutAnimation = css.keyframes('rotate360OutAnimation', {
  from: {
    transform: `translateX(-100%) rotate(0deg)`
  },
  to: {
    transform: `translateX(100%) rotate(360deg)`
  }
})

const SheetClose = ({ isClosing, ...props }) =>
  <Box {...css({
    cursor: 'pointer',
    transform: `translateX(-100%)`,
    backgroundColor: `rgba(255, 255, 255, 0.4)`,
    transition: `background-color ${theme.animationDuration.fast}`,
    animation: `${isClosing ? rotate360OutAnimation : rotate360InAnimation} ${theme.animationDuration.slow} ${theme.animationEasing.deceleration}`,
    '&:hover': {
      backgroundColor: `rgba(255, 255, 255, 0.6)`
    },
    '&:active': {
      backgroundColor: `rgba(255, 255, 255, 0.4)`
    }
  })} {...props}>
    <Close fill='#fff' />
  </Box>

SheetClose.defaultProps = {
  position: 'absolute',
  marginLeft: -4,
  marginTop: 4,
  padding: 2,
  circle: true
}

const slideInAnimation = css.keyframes('slideInAnimation', {
  from: {
    transform: `translateX(100%)`
  },
  to: {
    transform: `translateX(0)`
  }
})


const slideOutAnimation = css.keyframes('slideOutAnimation', {
  from: {
    transform: `translateX(0)`
  },
  to: {
    transform: `translateX(100%)`
  }
})

const SheetPane = ({ slideOut, ...props }) => <Pane {...css({
  transform: `translateZ(0)`,
  animation: `${slideOut ? slideOutAnimation : slideInAnimation} ${theme.animationDuration.slow} ${theme.animationEasing.deceleration}`
})} {...props} />

SheetPane.propTypes = {
  slideOut: PropTypes.bool
}

SheetPane.defaultProps = {
  white: true,
  position: 'absolute',
  shadow: true,
  top: 0,
  right: 0,
  bottom: 0
}

SheetPane.displayName = 'SheetPane'

class Sheet extends Component {
  constructor () {
    super()

    this.handleClose = this.handleClose.bind(this)
    this.handleAnimationEnd = this.handleAnimationEnd.bind(this)

    this.state = {
      isClosing: false
    }
  }

  handleClose () {
    this.setState({ isClosing: true })
  }

  handleAnimationEnd () {
    if (!this.state.isClosing) return
    this.props.onClose()
    this.setState({ isClosing: false })
  }

  render () {
    const { isOpen, children, ...props } = this.props
    const { isClosing } = this.state

    if (!isOpen) return null

    return (
      <Overlay onClick={this.handleClose} fadeOut={isClosing} onAnimationEnd={this.handleAnimationEnd}>
        <SheetPane slideOut={isClosing} {...props}>
          <SheetClose isClosing={isClosing} />
          {children}
        </SheetPane>
      </Overlay>
    )
  }
}

Sheet.propTypes = {
  width: PropTypes.string,
  isOpen: PropTypes.bool,
  onClose: PropTypes.func
}

Sheet.defaultProps = {
  width: '680px',
  isOpen: true
}

Sheet.displayName = 'Sheet'

export default Sheet
